#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "Non eseguire direttamente lo script app_upgrade. Per aggiornare un'applicazione, eseguire uno dei seguenti comandi:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilizzare -help per una descrizione completa dei comandi elencati."
;;

INVALID_START_DIR )
echo ""
echo "Tranne che durante l'utilizzo del parametro -help, lo script $2 non può essere eseguito da una directory diversa da $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "Il file '$2' contiene i valori dei parametri per lo script di aggiornamento."
echo "Se è necessario modificare i valori dei parametri predefiniti, è possibile modificare i file oppure specificare i valori come argomenti della riga comandi sugli script di aggiornamento."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "La seguente serie di file contiene i valori predefiniti dei parametri per un aggiornamento applicazione. Se è necessario modificare qualsiasi valore predefinito dei parametri, è possibile modificare tali file oppure specificare i valori come argomenti della riga comandi sugli script di aggiornamento."
echo "- Aggiornamento di DM:   $2/params/dm_params$3.sh"
echo "- Aggiornamento di VVC:  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Non è stato specificato un tipo di applicazione. Per aggiornare l'applicazione, eseguire uno dei seguenti comandi:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilizzare -help per una descrizione completa dei comandi elencati."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 non è un tipo di applicazione valido. Per aggiornare l'applicazione, eseguire uno dei seguenti comandi:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilizzare -help per una descrizione completa dei comandi elencati."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Manca un valore per il parametro $2."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "La directory $3, specificata per il parametro $2, non esiste o non è valida."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "La directory $3 specificata per il parametro $2 deve essere un percorso assoluto."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "Il file $3, specificato per il parametro $2 non esiste o non è valido."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 è un valore non valido per il parametro $2."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 è un parametro sconosciuto."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Manca il parametro della directory home $2."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "La directory $2 non esiste o non è valida."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "Impossibile trovare il comando repotools '$2' dell'applicazione."
echo ""
echo "Verificare che il parametro -oldApplicationHome '$3' punti alla vecchia directory di configurazione del server, ad esempio, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "Impossibile trovare il comando repotools '$2' dell'applicazione."
echo ""
echo "Verificare che il parametro -oldApplicationHome '$3' punti alla vecchia directory di configurazione del server, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Impossibile trovare il file di configurazione '$2'."
echo ""
echo "Verificare che il parametro -oldApplicationHome '$3' punti alla vecchia directory di configurazione del server, ad esempio, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Impossibile trovare il file di configurazione '$2'."
echo ""
echo "Verificare che il parametro -oldApplicationHome '$3' punti alla vecchia directory di configurazione del server, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "Impossibile trovare il comando repotools '$2' dell'applicazione."
echo ""
echo "Verificare che il parametro -newApplicationHome '$3' punti alla nuova directory di configurazione del server di applicazioni, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo "Se si sta effettuando l'aggiornamento da una release precedente, verificare di aver selezionato le root di contesto corrette. Ad esempio, se si utilizza Installation Manager, è necessario selezionare l'opzione della root di contesto $5 sul "Context Root Options" pannello. Se per errore è stata selezionata un'opzione differente, è necessario reinstallare il prodotto con l'opzione della root di contesto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Impossibile trovare il file di configurazione '$2'."
echo ""
echo "Verificare che il parametro -newApplicationHome '$3' punti alla nuova directory di configurazione del server JTS, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo "Se si sta effettuando l'aggiornamento da una release precedente, verificare di aver selezionato le root di contesto corrette. Ad esempio, se si utilizza Installation Manager, è necessario selezionare l'opzione della root di contesto $5 sul "Context Root Options" pannello. Se per errore è stata selezionata un'opzione differente, è necessario reinstallare il prodotto con l'opzione della root di contesto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Impossibile trovare il comando repotools JTS '$2'."
echo ""
echo "Verificare che il parametro -oldJTSHome '$3' punti alla vecchia directory di configurazione del server JTS, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Impossibile trovare il file di configurazione '$2'."
echo ""
echo "Verificare che il parametro -oldJTSHome '$3' punti alla vecchia directory di configurazione del server JTS, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Impossibile trovare il comando repotools JTS '$2'."
echo ""
echo "Verificare che il parametro -newJTSHome '$3' punti alla nuova directory di configurazione del server JTS, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Impossibile trovare il file di configurazione '$2'."
echo ""
echo "Verificare che il parametro -newJTSHome '$3' punti alla nuova directory di configurazione del server JTS, ad esempio, 'JazzInstallDir/server/conf' e che il parametro jtsContextRoot '$4' sia corretto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Per l'aggiornamento di $2 è necessario un file tar contenente dati 2.x."
echo "Utilizzare -help per una descrizione completa dei parametri."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    Aggiornamento di DM    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    Aggiornamento di VVC    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "L'ultima esecuzione non è riuscita al passo iniziale..."
;;

LAST_STEP_FAILED )
echo ""
echo "L'ultima esecuzione non è riuscita al passo $2..."
echo "Si desidera riavviare l'aggiornamento da questo passo o da un passo precedente?"
;;

ALREADY_RUN )
echo ""
echo "L'aggiornamento era stato già effettuato ed era terminato correttamente..."
echo "Si desidera riavviarne uno nuovo da un passo specifico?"
;;

LAST_STEP_PASSED )
echo ""
echo "L'ultima esecuzione è stata arrestata correttamente al passo $2..."
echo "Si desidera riavviare l'aggiornamento dal passo corrente $3 o da un passo precedente?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Immettere il numero di passo [$2-$3] desiderato da cui riavviare l'aggiornamento oppure premere [Invio] per annullare l'operazione:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' non è un numero. Immettere un numero di passo valido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' non è un numero di passo valido. Immettere un numero di passo valido."
;;

MAX_STEP_NUMBER )
echo ""
echo "L'ultimo passo è $2, pertanto non è possibile riavviare l'aggiornamento al passo $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "Il passo $2 non è stato ancora eseguito, pertanto non è possibile riavviare l'aggiornamento al passo $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Passo 0: Eliminare tabelle"
echo "--------------------------"
;;

STEP_0 )
echo "Passo 0: Aggiornare i file config"
echo "---------------------------------"
;;

STEP_1_ADD )
echo "Passo 1: Aggiungere tabelle"
echo "---------------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Passo $2: Generare nuovamente gli indici di testo"
echo "-------------------------------------------------"
;;

JFS_INDICES_STEP )
echo "Passo $2: Creare nuovamente gli indici di ricerca e query"
echo "---------------------------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Passo 2: Aggiornare lo schema del data warehouse"
echo "------------------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "L'aggiornamento di $2 non è riuscito al passo $3. Correggere il problema ed eseguire di nuovo lo script iniziando al passo $3."
echo "" 
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "L'aggiornamento di $2 è riuscito. Se è stato eseguito anche l'aggiornamento di JTS e VVC, ora è possibile avviare i server nella distribuzione."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "L'aggiornamento di $2 è riuscito. Se è stato eseguito anche l'aggiornamento di JTS e di qualsiasi applicazione dipendente (come DM), ora è possibile avviare i server nella distribuzione."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Directory: $2"
echo "Comando:"
;;

ENTER_STEP_ACTION )
echo "Immettere [E] per eseguire questo passo, [S] per ignorarlo o premere [Invio] per annullare l'esecuzione dello script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' è un'immissione non valida, sono consentiti solo 'E', 'S' o 'Invio'"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Verrà visualizzato un editor vi per consentire all'utente di verificare il file teamserver.properties $2."
echo "Verificare che la root dell'URI pubblico indicato dalla proprietà com.ibm.team.repository.server.webapp.url sia corretta."
echo "Verificare che le proprietà del database siano corrette."
echo "Una volta terminato, salvare le eventuali modifiche e chiudere l'editor per continuare l'esecuzione dello script."
echo ""
;;

PAUSE )
echo ""
echo "Immettere [C] per continuare l'esecuzione o premere [Invio] per annullare l'esecuzione dello script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' è un'immissione non valida, sono consentiti solo 'C' o 'Invio'"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Impossibile copiare gli indici di testo da '$2' a '$3'."
echo "Verificare la proprietà com.ibm.team.fulltext.indexLocation"
echo "definita nel file teamserver.properties."
echo "Copiare manualmente gli indici di testo in questa directory"
echo "oppure eseguire repotools -rebuildTextIndices per generarli nuovamente."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRORE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Non è stato definito un URI pubblico in"
echo "$3,"
echo "pertanto non è possibile avviare l'aggiornamento."
echo ""
echo "È necessario che in questo file sia definito un URI pubblico nel modo seguente:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La proprietà dell'URI pubblico com.ibm.team.repository.server.webapp.url deve essere presente nel file teamserver.properties."
echo "Aggiungere la proprietà al file teamserver.properties della vecchia installazione ed impostare il valore in modo che sia la root dell'URI che tutti i client utilizzano per raggiungere il server."
echo "La root dell'URI pubblico è necessaria per il corretto funzionamento della nuova installazione. L'aggiornamento non riuscirà senza questa proprietà.  "
echo "Per ulteriori informazioni, consultare l'argomento del Centro informazioni 'Pianificazione degli URI'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRORE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Tutti gli URI pubblici definiti in"
echo "$3,"
echo "sono contrassegnati come commento, pertanto l'aggiornamento non può iniziare."
echo ""
echo "È necessario che in questo file sia presente un URI pubblico non contrassegnato come commento e definito come segue:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La proprietà dell'URI pubblico com.ibm.team.repository.server.webapp.url deve essere presente nel file teamserver.properties."
echo "Aggiungere la proprietà al file teamserver.properties della vecchia installazione ed impostare il valore in modo che sia la root dell'URI che tutti i client utilizzano per raggiungere il server."
echo "La root dell'URI pubblico è necessaria per il corretto funzionamento della nuova installazione. L'aggiornamento non riuscirà senza questa proprietà."
echo "Per ulteriori informazioni, consultare l'argomento del Centro informazioni 'Pianificazione degli URI'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "La root di contesto per JTS è impostata su '$2'."
echo "La root di contesto per l'applicazione è impostata su '$3'."
echo "La root di contesto per JTS e quella per l'applicazione non possono essere uguali."
echo ""
;;

esac

}
